@@ -311,7 +311,7 @@ class MuminDataset:
             elif self.size == 'medium':
                 threshold = 0.75
             elif self.size == 'test':
-                threshold = 0.99
+                threshold = 0.999
 
             # Filter (:Tweet)-[:DISCUSSES]->(:Claim)
             discusses_rel = (self.rels[('tweet', 'discusses', 'claim')]
@@ -461,18 +461,20 @@ class MuminDataset:
 
             # Extract and store images
             if self.include_images and len(tweet_dfs['media']):
-                video_query = '(type == "video") or (type == "animated gif")'
-                video_df = (tweet_dfs['media']
-                            .query(video_query)
-                            .drop(columns=['url', 'duration_ms',
-                                           'public_metrics.view_count'])
-                            .rename(columns=dict(preview_image_url='url')))
                 image_df = (tweet_dfs['media']
                             .query('type == "photo"')
-                            .append(video_df)
                             .drop_duplicates(subset='media_key')
                             .reset_index(drop=True))
 
+                video_query = '(type == "video") or (type == "animated gif")'
+                if len(tweet_dfs['media'].query(video_query)):
+                    video_df = (tweet_dfs['media']
+                                .query(video_query)
+                                .drop(columns=['url', 'duration_ms',
+                                               'public_metrics.view_count'])
+                                .rename(columns=dict(preview_image_url='url')))
+                    image_df = image_df.append(video_df)
+
                 if 'media' in self.nodes.keys():
                     image_df = (self.nodes['media']
                                     .append(image_df)
@@ -1235,25 +1237,28 @@ class MuminDataset:
             self.nodes['image'] = image_df
 
             # (:Tweet)-[:HAS_IMAGE]->(:Image)
-            merged = (self.rels[('tweet', 'has_url', 'url')]
-                          .rename(columns=dict(src='tweet_idx', tgt='ul_idx'))
-                          .merge(self.nodes['url'][['url']]
-                                     .reset_index()
-                                     .rename(columns=dict(index='ul_idx')),
-                                 on='ul_idx')
-                          .merge(self.nodes['image'][['url']]
-                                     .reset_index()
-                                     .rename(columns=dict(index='im_idx')),
-                                 on='url'))
-            data_dict = dict(src=merged.tweet_idx.tolist(),
-                             tgt=merged.im_idx.tolist())
-            rel_df = pd.DataFrame(data_dict)
-            rel_type = ('tweet', 'has_image', 'image')
-            if rel_type in self.rels.keys():
-                rel_df = (self.rels[rel_type].append(rel_df)
-                                             .drop_duplicates()
-                                             .reset_index())
-            self.rels[rel_type] = rel_df
+            rel = ('tweet', 'has_url', 'url')
+            if rel in self.rels.keys() and len(self.rels[rel]):
+                merged = (self.rels[rel]
+                              .rename(columns=dict(src='tweet_idx',
+                                                   tgt='ul_idx'))
+                              .merge(self.nodes['url'][['url']]
+                                         .reset_index()
+                                         .rename(columns=dict(index='ul_idx')),
+                                     on='ul_idx')
+                              .merge(self.nodes['image'][['url']]
+                                         .reset_index()
+                                         .rename(columns=dict(index='im_idx')),
+                                     on='url'))
+                data_dict = dict(src=merged.tweet_idx.tolist(),
+                                 tgt=merged.im_idx.tolist())
+                rel_df = pd.DataFrame(data_dict)
+                rel_type = ('tweet', 'has_image', 'image')
+                if rel_type in self.rels.keys():
+                    rel_df = (self.rels[rel_type].append(rel_df)
+                                                 .drop_duplicates()
+                                                 .reset_index(drop=True))
+                self.rels[rel_type] = rel_df
 
             # (:Article)-[:HAS_TOP_IMAGE]->(:Image)
             rel = ('article', 'has_top_image_url', 'url')
